@@ -1,12 +1,14 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2021-01-30'; # DATE
-our $VERSION = '0.821'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-08'; # DATE
+our $DIST = 'Perinci-Examples'; # DIST
+our $VERSION = '0.822'; # VERSION
+
 our %SPEC;
 
 # package metadata
@@ -322,7 +324,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.821 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2021-01-30.
+This document describes version 0.822 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2022-03-08.
 
 =head1 DESCRIPTION
 
@@ -339,7 +341,7 @@ section).
 
 Usage:
 
- demo_cli_opts(%args) -> [status, msg, payload, meta]
+ demo_cli_opts(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Summary for `demo_cli_opts`.
 
@@ -349,7 +351,7 @@ Examples:
 
 =item * Summary for an example:
 
- demo_cli_opts( str1 => "a value", array1 => ["elem1", "elem2"], int1 => 10);
+ demo_cli_opts(str1 => "a value", array1 => ["elem1", "elem2"], int1 => 10);
 
 Result:
 
@@ -370,7 +372,7 @@ Result:
 
 =item * A second example:
 
- demo_cli_opts( str1 => "x", array1 => [1, 2], int1 => 20);
+ demo_cli_opts(str1 => "x", array1 => [1, 2], int1 => 20);
 
 Result:
 
@@ -381,11 +383,11 @@ Result:
    {
      logs => [
                {
-                 file    => "/home/s1/perl5/perlbrew/perls/perl-5.30.2/lib/site_perl/5.30.2/Perinci/Access/Schemeless.pm",
+                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.34.0/lib/site_perl/5.34.0/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
                  line    => 501,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1611968767,
+                 time    => 1646729751,
                  type    => "create",
                },
              ],
@@ -524,12 +526,12 @@ This demonstrate negation of --with-foo to --without-foo.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -539,7 +541,7 @@ Return value:  (any)
 
 Usage:
 
- demo_cli_opts_shorter(%args) -> [status, msg, payload, meta]
+ demo_cli_opts_shorter(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Function summary.
 
@@ -549,11 +551,7 @@ Examples:
 
 =item * Summary for an example:
 
- demo_cli_opts_shorter( str1 => "a value", bool1 => 1);
-
-Result:
-
- [200, "OK", { bool1 => 1, str1 => "a value" }, {}]
+ demo_cli_opts_shorter(str1 => "a value", bool1 => 1); # -> [200, "OK", { bool1 => 1, str1 => "a value" }, {}]
 
 =back
 
@@ -578,12 +576,12 @@ A required option as well as positional argument.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -595,14 +593,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Perinci>
@@ -613,11 +603,36 @@ L<Perinci::Examples>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
