@@ -1,12 +1,14 @@
 package Perinci::Examples::Stream;
 
-our $DATE = '2021-01-30'; # DATE
-our $VERSION = '0.821'; # VERSION
-
 use 5.010;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-08'; # DATE
+our $DIST = 'Perinci-Examples'; # DIST
+our $VERSION = '0.822'; # VERSION
+
 our %SPEC;
 
 $SPEC{':package'} = {
@@ -50,7 +52,7 @@ sub produce_ints {
     my $i = 1;
     my $num = $args{num};
     [200, "OK", sub {
-         return undef if defined($num) && $i > $num;
+         return undef if defined($num) && $i > $num; ## no critic: Subroutines::ProhibitExplicitReturnUndef
          $i++;
      }];
 }
@@ -114,7 +116,7 @@ sub produce_words {
     my $i = 1;
     my $num = $args{num};
     [200, "OK", sub {
-         return undef if defined($num) && $i > $num;
+         return undef if defined($num) && $i > $num; ## no critic: Subroutines::ProhibitExplicitReturnUndef
          $i++;
          join('', map { ['a'..'z']->[26*rand()] } 1..(int(6*rand)+5));
      }];
@@ -137,7 +139,7 @@ sub produce_words_err {
     my $i = 1;
     my $num = $args{num};
     [200, "OK", sub {
-         return undef if defined($num) && $i > $num;
+         return undef if defined($num) && $i > $num; ## no critic: Subroutines::ProhibitExplicitReturnUndef
          if ($i++ % 10 == 0) {
              "contain space";
          } else {
@@ -191,7 +193,7 @@ sub produce_hashes {
 
     my $i = 1;
     [200, "OK", sub {
-         return undef if defined($num) && $i > $num;
+         return undef if defined($num) && $i > $num; ## no critic: Subroutines::ProhibitExplicitReturnUndef
          {num=>$i++};
      }];
 }
@@ -219,7 +221,7 @@ sub square_nums {
 
     [200, "OK", sub {
          my $n = $input->();
-         return undef unless defined $n;
+         return undef unless defined $n; ## no critic: Subroutines::ProhibitExplicitReturnUndef
          $n*$n;
      }];
 }
@@ -368,7 +370,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.821 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2021-01-30.
+This document describes version 0.822 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2022-03-08.
 
 =head1 DESCRIPTION
 
@@ -382,7 +384,7 @@ This package contains functions that demonstrate streaming input/output.
 
 Usage:
 
- count_ints(%args) -> [status, msg, payload, meta]
+ count_ints(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function accepts a stream of integers and return the number of integers input.
 
@@ -401,12 +403,12 @@ Numbers.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -416,7 +418,7 @@ Return value:  (any)
 
 Usage:
 
- count_lines(%args) -> [status, msg, payload, meta]
+ count_lines(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Count number of lines in the input.
 
@@ -435,12 +437,12 @@ Lines.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -450,7 +452,7 @@ Return value:  (any)
 
 Usage:
 
- count_words(%args) -> [status, msg, payload, meta]
+ count_words(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function receives a stream of words and return the number of words.
 
@@ -469,12 +471,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -484,7 +486,7 @@ Return value:  (any)
 
 Usage:
 
- produce_hashes(%args) -> [status, msg, payload, meta]
+ produce_hashes(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function produces a stream of hashes.
 
@@ -505,12 +507,12 @@ The default is to produce an infinite number.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[hash])
 
@@ -520,7 +522,7 @@ Return value:  (array[hash])
 
 Usage:
 
- produce_ints(%args) -> [status, msg, payload, meta]
+ produce_ints(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function produces a stream of integers, starting from 1.
 
@@ -541,12 +543,12 @@ The default is to produce an infinite number.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[int])
 
@@ -556,7 +558,7 @@ Return value:  (array[int])
 
 Usage:
 
- produce_words(%args) -> [status, msg, payload, meta]
+ produce_words(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function produces a stream of random words.
 
@@ -577,12 +579,12 @@ The default is to produce an infinite number.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[str])
 
@@ -592,7 +594,7 @@ Return value:  (array[str])
 
 Usage:
 
- produce_words_err(%args) -> [status, msg, payload, meta]
+ produce_words_err(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Like `produce_words()`, but 1 in every 10 words will be a non-word (which fails the result schema).
 
@@ -613,12 +615,12 @@ The default is to produce an infinite number.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[str])
 
@@ -628,7 +630,7 @@ Return value:  (array[str])
 
 Usage:
 
- square_nums(%args) -> [status, msg, payload, meta]
+ square_nums(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function squares its stream input.
 
@@ -645,12 +647,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[float])
 
@@ -660,7 +662,7 @@ Return value:  (array[float])
 
 Usage:
 
- square_nums_from_file(%args) -> [status, msg, payload, meta]
+ square_nums_from_file(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function squares its stream input.
 
@@ -677,12 +679,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[float])
 
@@ -692,7 +694,7 @@ Return value:  (array[float])
 
 Usage:
 
- square_nums_from_stdin(%args) -> [status, msg, payload, meta]
+ square_nums_from_stdin(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function squares its stream input.
 
@@ -709,12 +711,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[float])
 
@@ -724,7 +726,7 @@ Return value:  (array[float])
 
 Usage:
 
- square_nums_from_stdin_or_file(%args) -> [status, msg, payload, meta]
+ square_nums_from_stdin_or_file(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function squares its stream input.
 
@@ -741,12 +743,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (array[float])
 
@@ -756,7 +758,7 @@ Return value:  (array[float])
 
 Usage:
 
- wc(%args) -> [status, msg, payload, meta]
+ wc(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Count the number of linesE<sol>wordsE<sol>characters of input, like the "wc" command.
 
@@ -773,12 +775,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (hash)
 
@@ -788,7 +790,7 @@ Return value:  (hash)
 
 Usage:
 
- wc_keys(%args) -> [status, msg, payload, meta]
+ wc_keys(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Count the number of keys of each hash.
 
@@ -808,12 +810,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (hash)
 
@@ -825,6 +827,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples>
@@ -833,15 +863,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
