@@ -1,7 +1,10 @@
+## no critic: RequireUseStrict
 package Perinci::Examples::Tiny::Args;
 
-our $DATE = '2021-01-30'; # DATE
-our $VERSION = '0.821'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-08'; # DATE
+our $DIST = 'Perinci-Examples'; # DIST
+our $VERSION = '0.822'; # VERSION
 
 our %SPEC;
 
@@ -131,7 +134,7 @@ Perinci::Examples::Tiny::Args - Tests related to function arguments
 
 =head1 VERSION
 
-This document describes version 0.821 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2021-01-30.
+This document describes version 0.822 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2022-03-08.
 
 =head1 DESCRIPTION
 
@@ -146,7 +149,7 @@ Perinci::CmdLine frameworks.
 
 Usage:
 
- as_is(%args) -> [status, msg, payload, meta]
+ as_is(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function returns the argument as-is.
 
@@ -163,12 +166,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -178,7 +181,7 @@ Return value:  (any)
 
 Usage:
 
- has_date_and_duration_args(%args) -> [status, msg, payload, meta]
+ has_date_and_duration_args(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function contains a date and a duration argument.
 
@@ -197,12 +200,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -212,7 +215,7 @@ Return value:  (any)
 
 Usage:
 
- has_date_arg(%args) -> [status, msg, payload, meta]
+ has_date_arg(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function contains a date argument.
 
@@ -229,12 +232,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -244,7 +247,7 @@ Return value:  (any)
 
 Usage:
 
- has_dot_args(%args) -> [status, msg, payload, meta]
+ has_dot_args(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function contains arguments with dot in their names.
 
@@ -263,12 +266,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value: Return the two numbers multiplied (any)
 
@@ -278,7 +281,7 @@ Return value: Return the two numbers multiplied (any)
 
 Usage:
 
- has_duration_arg(%args) -> [status, msg, payload, meta]
+ has_duration_arg(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 This function contains a duration argument.
 
@@ -295,12 +298,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -312,6 +315,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples>
@@ -320,15 +351,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
